import React, {useState, useEffect} from 'react'

import { MetaPlate } from 'metaplate'
import 'metaplate/dist/index.css'


const shopUrl = 'http://shop-roles.asmer.fs.a-level.com.ua/'

const getGQL = (url=shopUrl + 'graphql', headers={}) => 
    (query="", variables={}) => 
        fetch(url, 
                      {method: 'POST',
                            headers: {
                              'Accept': 'application/json',
                              'Content-Type': 'application/json',
                              ...headers  
                            },
                           body: JSON.stringify({query,variables})
                          })
        .then(res => res.json())

const Image = ({src}) => <img src={`${shopUrl}${src}`} />

const Good = ({good, children}) =>
good ? 
<div className='Good'>
    <h2>{good.name}</h2>
    <p>{good.description}</p>
    <money>{good.price}</money>
    {children}
</div>
: <h3>null</h3>

const Category = ({category:{name, _id}, children}) =>
<div className='Category'>
    <h1>{name}</h1>
    {children}
</div>

const Categories = ({children, data}) => 
<div style={{border: '2px solid', paddingLeft: '20px'}}>
    <h1>categories({data && data.length})</h1>
    {children}
</div>

const Goods = ({children}) => 
<div style={{border: '2px solid blue', paddingLeft: '10px'}}>
    <h2>goods</h2>
    {children}
</div>

const MetaTest = () => {
    const [data, setData] = useState()

    const query =
        `query MainCategories{
              CategoryFind(query: "[{}]"){
                _id name
                  image{
                    url
                  }
                goods{
                name description price images{
                  url
                }
              }
                subCategories{ name }
            }
        }
    `
    useEffect(() => {
        getGQL()(query).then(data => setData(data.data.CategoryFind))
    },[])

    return (
        <MetaPlate data={data}>
            <Categories prop='data'>
                <Category prop="category" keyDataKey="_id">
                    <Goods sourceDataKey="goods"> 
                        <Good prop="good" keyDataKey="_id">
                            <div sourceDataKey="images">
                                <Image prop="src" sourceDataKey="url" />
                            </div>
                        </Good>
                    </Goods>
                    <Categories sourceDataKey="subCategories" prop='data'>
                        <Category prop="category" keyDataKey="_id" />
                    </Categories>
                </Category>
            </Categories>
        </MetaPlate>)
}



const App = () => 
<>
  <MetaTest />
</>


export default App
